<?php
namespace Webshop\Product;

/**
 * Class Product
 *
 * @package Webshop\Product
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/webshop-product
 */
class Product implements ProductInterface
{
    /** @var int */
    protected $id;
    /** @var string */
    protected $name;
    /** @var string */
    protected $type;
    /** @var string */
    protected $catalogNumber;
    /** @var string */
    protected $sku;
    /** @var string */
    protected $supplier;

    /**
     * Vraća ID proizvoda.
     *
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name ?? 'Bez naziva';
    }

    /**
     * Vraća vrstu proizvoda.
     *
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * Kataloški broj proizvoda kod dobavljača, ovo koristimo za naručivanje od njih.
     *
     * @return string|null
     */
    public function getCatalogNumber(): ?string
    {
        return $this->catalogNumber;
    }

    /**
     * Vraća šifru proizvoda.
     *
     * @return string
     */
    public function getSku(): string
    {
        return $this->sku;
    }

    /**
     * Vraća šifru dobavljača ovog proizvoda.
     *
     * @return string|null
     */
    public function getSupplier(): ?string
    {
        return $this->supplier;
    }
}